==> jc-1.4.0.tar.gz: java/awt/event/MouseMotionAdapter.h <==
// public abstract class java.awt.event.MouseMotionAdapter

// class file dependencies
// @dep_class 7be49a9ebc11cb6e java_awt_event_MouseMotionAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_MouseMotionAdapter_H_
#define _JC_java_awt_event_MouseMotionAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_MouseMotionAdapter$sub_refs	_jc_java_awt_event_MouseMotionAdapter$sub_refs;
typedef struct _jc_java_awt_event_MouseMotionAdapter$sub_nonrefs	_jc_java_awt_event_MouseMotionAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_MouseMotionAdapter$refs	_jc_java_awt_event_MouseMotionAdapter$refs;
typedef struct _jc_java_awt_event_MouseMotionAdapter$nonrefs	_jc_java_awt_event_MouseMotionAdapter$nonrefs;
typedef struct _jc_java_awt_event_MouseMotionAdapter$object	_jc_java_awt_event_MouseMotionAdapter$object;

typedef const struct _jc_java_awt_event_MouseMotionAdapter$vmethods	_jc_java_awt_event_MouseMotionAdapter$vmethods;
typedef const struct _jc_java_awt_event_MouseMotionAdapter$vtable	_jc_java_awt_event_MouseMotionAdapter$vtable;
typedef const struct _jc_java_awt_event_MouseMotionAdapter$vtype	_jc_java_awt_event_MouseMotionAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_MouseMotionAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_MouseMotionAdapter$object *);

// Virtual methods
extern void _jc_java_awt_event_MouseMotionAdapter$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_java_awt_event_MouseMotionAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_java_awt_event_MouseMotionAdapter$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_java_awt_event_MouseMotionAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_MouseMotionAdapter$method_info$mouseDragged$3079e58fafa0fefe;
extern _jc_method _jc_java_awt_event_MouseMotionAdapter$method_info$mouseMoved$9e3a895f548fc637;

// Virtual methods structure
struct _jc_java_awt_event_MouseMotionAdapter$vmethods {
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_java_awt_event_MouseMotionAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_java_awt_event_MouseMotionAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
};

// Vtable
struct _jc_java_awt_event_MouseMotionAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseMotionAdapter$vmethods	java_awt_event_MouseMotionAdapter;
};

// Vtype
struct _jc_java_awt_event_MouseMotionAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_MouseMotionAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_MouseMotionAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_MouseMotionAdapter$refs {
    _jc_java_awt_event_MouseMotionAdapter$sub_refs	java_awt_event_MouseMotionAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_MouseMotionAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_MouseMotionAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseMotionAdapter$sub_nonrefs	java_awt_event_MouseMotionAdapter;
};

// Object instance structure
struct _jc_java_awt_event_MouseMotionAdapter$object {
	_jc_java_awt_event_MouseMotionAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_MouseMotionAdapter$vtype	*vtype;
	_jc_java_awt_event_MouseMotionAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_MouseMotionAdapter$vtype _jc_java_awt_event_MouseMotionAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_MouseMotionAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_MouseMotionAdapter$class_object;

#endif	/* _JC_java_awt_event_MouseMotionAdapter_H_ */

==> jc-1.4.6.tar.gz: java/awt/event/MouseMotionAdapter.h <==
// public abstract class java.awt.event.MouseMotionAdapter

// class file dependencies
// @dep_class 7be49a9ebc11cb6e java_awt_event_MouseMotionAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_MouseMotionAdapter_H_
#define _JC_java_awt_event_MouseMotionAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_MouseMotionAdapter$sub_refs	_jc_java_awt_event_MouseMotionAdapter$sub_refs;
typedef struct _jc_java_awt_event_MouseMotionAdapter$sub_nonrefs	_jc_java_awt_event_MouseMotionAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_MouseMotionAdapter$refs	_jc_java_awt_event_MouseMotionAdapter$refs;
typedef struct _jc_java_awt_event_MouseMotionAdapter$nonrefs	_jc_java_awt_event_MouseMotionAdapter$nonrefs;
typedef struct _jc_java_awt_event_MouseMotionAdapter$object	_jc_java_awt_event_MouseMotionAdapter$object;

typedef const struct _jc_java_awt_event_MouseMotionAdapter$vmethods	_jc_java_awt_event_MouseMotionAdapter$vmethods;
typedef const struct _jc_java_awt_event_MouseMotionAdapter$vtable	_jc_java_awt_event_MouseMotionAdapter$vtable;
typedef const struct _jc_java_awt_event_MouseMotionAdapter$vtype	_jc_java_awt_event_MouseMotionAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_MouseMotionAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_MouseMotionAdapter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_event_MouseMotionAdapter$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_java_awt_event_MouseMotionAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_MouseMotionAdapter$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_java_awt_event_MouseMotionAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_MouseMotionAdapter$method_info$mouseDragged$3079e58fafa0fefe;
extern _jc_method _jc_java_awt_event_MouseMotionAdapter$method_info$mouseMoved$9e3a895f548fc637;

// Virtual methods structure
struct _jc_java_awt_event_MouseMotionAdapter$vmethods {
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_java_awt_event_MouseMotionAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_java_awt_event_MouseMotionAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_MouseMotionAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseMotionAdapter$vmethods	java_awt_event_MouseMotionAdapter;
};

// Vtype
struct _jc_java_awt_event_MouseMotionAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_MouseMotionAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_MouseMotionAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_MouseMotionAdapter$refs {
    _jc_java_awt_event_MouseMotionAdapter$sub_refs	java_awt_event_MouseMotionAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_MouseMotionAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_MouseMotionAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseMotionAdapter$sub_nonrefs	java_awt_event_MouseMotionAdapter;
};

// Object instance structure
struct _jc_java_awt_event_MouseMotionAdapter$object {
	_jc_java_awt_event_MouseMotionAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_MouseMotionAdapter$vtype	*vtype;
	_jc_java_awt_event_MouseMotionAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_MouseMotionAdapter$vtype _jc_java_awt_event_MouseMotionAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_MouseMotionAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_MouseMotionAdapter$class_object;

#endif	/* _JC_java_awt_event_MouseMotionAdapter_H_ */
